@@ -1,4 +1,4 @@
-#!/usr/bin/python3.4
+#!/usr/bin/python2.7
 # SOCKSv5 proxy server for network-sandbox
 # Copyright 2015 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
@@ -83,6 +83,11 @@ class Socks5Server(object):
 				data = yield from reader.readexactly(1)
 				addr_len, = struct.unpack('!B', data)
 				addr = yield from reader.readexactly(addr_len)
+				try:
+					addr = addr.decode('idna')
+				except UnicodeDecodeError:
+					rpl = 0x04  # host unreachable
+
 			elif atyp == 0x04:  # IPv6
 				data = yield from reader.readexactly(16)
 				addr = socket.inet_ntop(socket.AF_INET6, data)
