@@ -3,9 +3,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'hppa2.0-unknown-linux-gnu-ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Parser/asdl_c.py',
- 'ASDLGEN_FILES': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Parser/asdl.py /var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Parser/asdl_c.py',
- 'AST_ASDL': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Parser/Python.asdl',
+ 'ASDLGEN': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Parser/asdl_c.py',
+ 'ASDLGEN_FILES': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Parser/asdl.py /var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Parser/asdl_c.py',
+ 'AST_ASDL': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
@@ -25,11 +25,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -O2 -pipe -march=2.0 -fwrapv -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/usr' '--build=hppa2.0-unknown-linux-gnu' '--host=hppa2.0-unknown-linux-gnu' '--mandir=/usr/share/man' '--infodir=/usr/share/info' '--datadir=/usr/share' '--sysconfdir=/etc' '--localstatedir=/var/lib' '--libdir=/usr/lib' '--with-fpectl' '--enable-shared' '--enable-ipv6' '--with-threads' '--enable-unicode=ucs4' '--infodir=/usr/share/info' '--mandir=/usr/share/man' '--with-dbmliborder=gdbm' '--with-libc=' '--enable-loadable-sqlite-extensions' '--with-system-expat' '--with-system-ffi' '--without-ensurepip' 'build_alias=hppa2.0-unknown-linux-gnu' 'host_alias=hppa2.0-unknown-linux-gnu' 'CFLAGS=-O2 -pipe -march=2.0 -fwrapv' 'LDFLAGS=-Wl,-O1 -Wl,--as-needed -L.' 'CPPFLAGS=' 'PKG_CONFIG_PATH=/usr/lib/pkgconfig'",
+ 'CONFIG_ARGS': "'--prefix=/usr' '--build=hppa2.0-unknown-linux-gnu' '--host=hppa2.0-unknown-linux-gnu' '--mandir=/usr/share/man' '--infodir=/usr/share/info' '--datadir=/usr/share' '--sysconfdir=/etc' '--localstatedir=/var/lib' '--libdir=/usr/lib' '--with-fpectl' '--enable-shared' '--enable-ipv6' '--with-threads' '--enable-unicode=ucs4' '--infodir=/usr/share/info' '--mandir=/usr/share/man' '--with-computed-gotos' '--with-dbmliborder=gdbm' '--with-libc=' '--enable-loadable-sqlite-extensions' '--with-system-expat' '--with-system-ffi' '--without-ensurepip' 'build_alias=hppa2.0-unknown-linux-gnu' 'host_alias=hppa2.0-unknown-linux-gnu' 'CFLAGS=-O2 -pipe -march=2.0 -fwrapv' 'LDFLAGS=-Wl,-O1 -Wl,--as-needed -L.' 'CPPFLAGS=' 'PKG_CONFIG_PATH=/usr/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'CPPFLAGS': '-I. -IInclude -I/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Include',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-2.7.12/work/hppa2.0-unknown-linux-gnu/coverage.info',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-2.7.12/work/hppa2.0-unknown-linux-gnu/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
+ 'CPPFLAGS': '-I. -IInclude -I/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Include',
  'CXX': 'hppa2.0-unknown-linux-gnu-g++ -pthread',
  'C_THREADS': 0,
  'DESTDIRS': '/usr /usr/lib /usr/lib/python2.7 /usr/lib/python2.7/lib-dynload',
@@ -62,7 +65,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'GNULD': 'yes',
  'GRAMMAR_C': 'Python/graminit.c',
  'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Grammar/Grammar',
+ 'GRAMMAR_INPUT': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -87,6 +90,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
+ 'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
@@ -237,6 +241,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
+ 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
  'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
@@ -287,7 +292,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRUCT_STAT_ST_GEN': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
- 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
@@ -386,6 +390,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
  'LINKCC': 'hppa2.0-unknown-linux-gnu-gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
+ 'LLVM_PROF_ERR': 'no',
+ 'LLVM_PROF_FILE': '',
+ 'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux2',
@@ -398,7 +405,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MAINCC': 'hppa2.0-unknown-linux-gnu-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Modules/makesetup',
+ 'MAKESETUP': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/bin/mkdir -p',
@@ -409,6 +416,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
+ 'OPCODETARGETGEN': '\\',
+ 'OPCODETARGETGEN_FILES': '\\',
+ 'OPCODETARGETS_H': '\\',
  'OPT': '-DNDEBUG',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -423,13 +433,15 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-linux2',
  'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -443,7 +455,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe -march=2.0 -fwrapv -DNDEBUG -I. -IInclude -I/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe -march=2.0 -fwrapv -DNDEBUG -I. -IInclude -I/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'unsigned long',
@@ -455,7 +467,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'hppa2.0-unknown-linux-gnu-ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-2.7.10-r1/work/hppa2.0-unknown-linux-gnu',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-2.7.12/work/hppa2.0-unknown-linux-gnu',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -484,7 +496,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
- 'SRC_GDB_HOOKS': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
@@ -498,8 +510,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
- 'TESTPROG': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10/Lib/test/regrtest.py',
- 'TESTPYTHON': '_PYTHONNOSITEPACKAGES=1 LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-2.7.10-r1/work/hppa2.0-unknown-linux-gnu ./python -Wd -3 -E -tt',
+ 'TESTPROG': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12/Lib/test/regrtest.py',
+ 'TESTPYTHON': '_PYTHONNOSITEPACKAGES=1 LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-2.7.12/work/hppa2.0-unknown-linux-gnu ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -507,10 +519,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TM_IN_SYS_TIME': 0,
  'UNICODE_OBJS': 'Objects/unicodeobject.o Objects/unicodectype.o',
  'UNIVERSALSDK': '',
+ 'USE_COMPUTED_GOTOS': 1,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
- 'VPATH': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10',
+ 'VPATH': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12',
  'WANT_SIGFPE_HANDLER': 1,
  'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 1,
@@ -524,11 +537,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/hppa2.0-unknown-linux-gnu',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-2.7.12/work/hppa2.0-unknown-linux-gnu',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12',
  'build': 'hppa2.0-unknown-linux-gnu',
+ 'cross_compiling': 'no',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'host': 'hppa2.0-unknown-linux-gnu',
  'prefix': '/usr',
- 'srcdir': '/var/tmp/portage/dev-lang/python-2.7.10-r1/work/Python-2.7.10'}
+ 'srcdir': '/var/tmp/portage/dev-lang/python-2.7.12/work/Python-2.7.12'}
